package envoy.client.ui.list_component;

import java.awt.BorderLayout;
import java.awt.Dimension;

import javax.swing.JLabel;
import javax.swing.JPanel;

import envoy.client.data.Settings;
import envoy.client.ui.Color;
import envoy.client.ui.Theme;
import envoy.data.User;
import envoy.data.User.UserStatus;

/**
 * Displays a {@link User}.<br>
 * <br>
 * Project: <strong>envoy-client</strong>
 * File: <strong>UserComponent.java</strong>
 * Created: <strong>21.03.2020</strong>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Client v0.1-beta
 */
public class UserComponent extends JPanel {

	private static final long serialVersionUID = 0L;

	/**
	 * @param user the {@link User} whose information is displayed
	 * @since Envoy Client v0.1-beta
	 */
	public UserComponent(User user) {
		final Theme theme = Settings.getInstance().getCurrentTheme();

		setLayout(new BorderLayout());

		// Panel background
		setBackground(theme.getCellColor());
		setOpaque(true);
		setPreferredSize(new Dimension(100, 35));

		// TODO add profile picture support in BorderLayout.West

		JLabel username = new JLabel(user.getName());
		username.setForeground(theme.getUserNameColor());
		add(username, BorderLayout.CENTER);

		final UserStatus	status		= user.getStatus();
		JLabel				statusLabel	= new JLabel(status.toString());
		Color				foreground;
		switch (status) {
			case AWAY:
				foreground = Color.yellow;
				break;
			case BUSY:
				foreground = Color.blue;
				break;
			case ONLINE:
				foreground = Color.green;
				break;
			default:
				foreground = Color.lightGray;
				break;
		}
		statusLabel.setForeground(foreground);
		add(statusLabel, BorderLayout.NORTH);
	}
}
